@@ -54,8 +54,8 @@ downloads, installation and source code.
 
 __Conventions__  = 'CF-1.6'
 __author__       = 'David Hassell'
-__date__         = '2018-07-24'
-__version__      = '2.2.7'
+__date__         = '2018-10-22'
+__version__      = '2.3.0'
 
 from distutils.version import LooseVersion, StrictVersion
 import imp
@@ -77,6 +77,27 @@ except ImportError:
 else:
     _found_ESMF = True
 
+try:
+    from mpi4py import MPI
+
+    mpi_comm = MPI.COMM_WORLD
+    mpi_size = mpi_comm.Get_size()
+    mpi_rank = mpi_comm.Get_rank()
+
+    if mpi_size > 1:
+        mpi_on = True
+        if mpi_rank == 0:
+            print '==============================================='
+            print 'WARNING: MPI support is an experimental feature'
+            print '  and is not recommended for operational use.'
+            print '==============================================='
+    else:
+        mpi_on = False
+    #--- End: if
+except ImportError:
+    mpi_on = False
+#--- End: try
+
 from .variable             import Variable
 from .boundedvariable      import BoundedVariable, Bounds
 from .coordinate           import Coordinate, DimensionCoordinate, AuxiliaryCoordinate
