@@ -6,6 +6,11 @@ from tempfile import gettempdir
 from numpy.ma import masked as numpy_ma_masked
 from numpy.ma import nomask as numpy_ma_nomask
 
+from . import mpi_on
+if mpi_on:
+    from . import mpi_size
+#--- End: if
+
 #platform = sys.platform
 #if platform == 'darwin':
 #    from psutil import virtual_memory
@@ -74,20 +79,33 @@ _TOTAL_MEMORY = float(virtual_memory().total)
 #	    the default directory used by the :mod:`tempfile` module.
 #
 #        REGRID_LOGGING : bool
-#        Whether or not to enable ESMPy logging. If it is logging is performed
-#        after every call to ESMPy. By default logging is disabled.
+#           Whether or not to enable ESMPy logging. If it is logging
+#           is performed after every call to ESMPy. By default logging
+#           is disabled.
+#
+#        FREE_MEMORY_FACTOR : int
+#           Factor to divide the free memory by. If MPI is on this is
+#           equal to the number of PEs. Otherwise it is equal to 1 and
+#           is ignored in any case.
+#
+#        COLLAPSE_PARALLEL_MODE : int
+#           The mode to use when parallelising collapse. By default
+#           this is 0 to try and automatically determine which mode to
+#           use.
 #
 # --------------------------------------------------------------------
-CONSTANTS = {'RTOL'              : sys.float_info.epsilon,
-             'ATOL'              : sys.float_info.epsilon,
-             'TEMPDIR'           : gettempdir(),
-             'MINNCFM'           : 10,
-             'OF_FRACTION'       : 0.5,
-             'TOTAL_MEMORY'      : _TOTAL_MEMORY,
-             'CHUNKSIZE'         : _TOTAL_MEMORY * 0.01,
-             'REGRID_LOGGING'    : False,
-             'RELAXED_IDENTITIES': False,
-             'IGNORE_IDENTITIES' : False,
+CONSTANTS = {'RTOL'                  : sys.float_info.epsilon,
+             'ATOL'                  : sys.float_info.epsilon,
+             'TEMPDIR'               : gettempdir(),
+             'MINNCFM'               : 10,
+             'OF_FRACTION'           : 0.5,
+             'TOTAL_MEMORY'          : _TOTAL_MEMORY,
+             'CHUNKSIZE'             : _TOTAL_MEMORY * 0.01,
+             'FREE_MEMORY_FACTOR'    : mpi_size if mpi_on else 1,
+             'REGRID_LOGGING'        : False,
+             'COLLAPSE_PARALLEL_MODE': 0,
+             'RELAXED_IDENTITIES'    : False,
+             'IGNORE_IDENTITIES'     : False,
              }
 
 CONSTANTS['FM_THRESHOLD'] = CONSTANTS['MINNCFM']*CONSTANTS['CHUNKSIZE']
