@@ -47,7 +47,7 @@ def asanyarray(*args):
     '''
     out = []
     for x in args:
-        if not numpy_ndim(x):
+        if x is not None and not numpy_ndim(x):
             # Make sure that we have a numpy array (as opposed to, e.g. a
             # numpy.float64)
             out.append(numpy_asanyarray(x))
@@ -55,10 +55,11 @@ def asanyarray(*args):
             out.append(x)
     #--- End: for
 
-    if len(out) == 1:
-        return out[0]
-    else:
-        return out
+    # if len(out) == 1:
+    #     return out[0]
+    # else:
+    #     return out
+    return out
 #--- End: def
 
 def psum(x, y):
@@ -281,7 +282,7 @@ axis.
         The sample sizes and the maxima.
 
 '''
-    N    = sample_size_f(a, axis=axis, masked=masked)
+    N,   = sample_size_f(a, axis=axis, masked=masked)
     amax = numpy_amax(a, axis=axis)
 
     if not numpy_ndim(amax):
@@ -292,7 +293,7 @@ axis.
     return asanyarray(N, amax)
 #--- End: def
 
-def max_fpartial(out, out1=None):
+def max_fpartial(out, out1=None, group=False):
     N, amax = out
 
     if out1 is not None:
@@ -339,13 +340,13 @@ axis.
         The sample sizes and the minima.
      
 '''
-    N    = sample_size_f(a, axis=axis, masked=masked)
+    N,   = sample_size_f(a, axis=axis, masked=masked)
     amin = numpy_amin(a, axis=axis)
 
     return asanyarray(N, amin)
 #--- End: def
 
-def min_fpartial(out, out1=None):
+def min_fpartial(out, out1=None, group=False):
     '''
 '''
     N, amin = out
@@ -415,14 +416,14 @@ The weighted average along the specified axes.
         sw  = numpy_asanyarray(sw)
 
     if weights is None:
-        N = sw.copy()
+        N  = sw.copy()
     else:
-        N = sample_size_f(a, axis=axis, masked=masked)
+        N, = sample_size_f(a, axis=axis, masked=masked)
         
     return asanyarray(N, avg, sw)
 #--- End: def
 
-def mean_fpartial(out, out1=None):
+def mean_fpartial(out, out1=None, group=False):
     '''Return the partial sample size,the partial sum and partial sum of
 the weights.
 
@@ -442,7 +443,7 @@ the weights.
     '''
     N, avg, sw = out
     
-    if out1 is None:
+    if out1 is None and not group:
         # This is the first partition to be processed
 
         # Convert the partition average to a partition sum
@@ -452,7 +453,8 @@ the weights.
         N1, avg1, sw1 = out1
 
         # Convert the partition average to a partition sum
-        avg1 *= sw1
+        if not group:
+            avg1 *= sw1
         
         N   = psum(N, N1)
         avg = psum(avg, avg1) # Now a partial sum
@@ -517,7 +519,7 @@ axis=axis), numpy.amax(a, axis=axis))``
         The minimum and maximum inside a 2-tuple.
 
 '''
-    N    = sample_size_f(a, axis=axis, masked=masked)
+    N,   = sample_size_f(a, axis=axis, masked=masked)
     amin = numpy_amin(a, axis=axis)
     amax = numpy_amax(a, axis=axis)
 
@@ -530,7 +532,7 @@ axis=axis), numpy.amax(a, axis=axis))``
     return asanyarray(N, amin, amax)
 #--- End: def
 
-def mid_range_fpartial(out, out1=None):
+def mid_range_fpartial(out, out1=None, group=False):
     '''
 '''
     N, amin, amax = out
@@ -627,31 +629,32 @@ def sample_size_f(a, axis=None, masked=False):
     return asanyarray(N)
 #--- End: def
 
-def sample_size_fpartial(N, out1=None):
+def sample_size_fpartial(out, out1=None, group=False):
     '''
 
 :Parameters:
 
-    N : numpy array
+    out : ordered sequence of one numpy array
 
 :Returns:
 
     out : numpy array
 
 '''
+    N, = out
     if out1 is not None:
-        N1 = out1
+        N1, = out1
         N = psum(N, N1)
 
     return asanyarray(N)
 #--- End: def
 
-def sample_size_ffinalise(N, sub_samples=None):
+def sample_size_ffinalise(out, sub_samples=None):
     '''
 
 :Parameters:
 
-    N : numpy array
+    out : ordered sequence of one numpy array
 
     sub_samples : *optional*
         Ignored.
@@ -662,6 +665,7 @@ def sample_size_ffinalise(N, sub_samples=None):
         A 2-tuple containing *N* twice.
 
 '''
+    N, = out
     return asanyarray(N, N)
 #--- End: def
 
@@ -695,7 +699,7 @@ axis=axis),)``
 '''
     a = double_precision(a)
     
-    N    = sample_size_f(a, axis=axis, masked=masked)
+    N,   = sample_size_f(a, axis=axis, masked=masked)
     asum = a.sum(axis=axis)
 
     if not numpy_ndim(asum):
@@ -704,7 +708,7 @@ axis=axis),)``
     return asanyarray(N, asum)
 #--- End: def
 
-def sum_fpartial(out, out1=None):
+def sum_fpartial(out, out1=None, group=False):
     '''
 '''
     N, asum = out
@@ -735,7 +739,7 @@ def sw_f(a, axis=None, masked=False, weights=None, N=None,
     '''
 '''
     if N is None:
-        N = sample_size_f(a, axis=axis, masked=masked)
+        N, = sample_size_f(a, axis=axis, masked=masked)
 
     if weights is not None:
         # A weights array has been provided
@@ -856,7 +860,7 @@ weighted  Whether or not the sample is weighted
     return (N, var, avg, V1, V2, ddof, weighted)
 #--- End: def
 
-def var_fpartial(out, out1=None):
+def var_fpartial(out, out1=None, group=False):
     '''Return:
 
 * The partial sum sample sizes
@@ -897,7 +901,7 @@ https://en.wikipedia.org/wiki/Pooled_variance#Population-based_statistics
     '''
     (N, var, avg, V1, V2, ddof, weighted) = out
 
-    if out1 is None:
+    if out1 is None and not group:
         # ------------------------------------------------------------
         # var = V1(var+avg**2)
         # avg = V1*avg = unweighted partial sum
@@ -916,9 +920,10 @@ https://en.wikipedia.org/wiki/Pooled_variance#Population-based_statistics
 
         N = psum(N, Nb)
         
-        varb += avgb*avgb
-        varb *= V1b
-        avgb *= V1b
+        if not group:
+            varb += avgb*avgb
+            varb *= V1b
+            avgb *= V1b
 
         var = psum(var, varb)
         avg = psum(avg, avgb)
