@@ -18,7 +18,9 @@ def read(files, verbose=False, ignore_read_error=False,
          aggregate=True, nfields=None, squeeze=False, unsqueeze=False,
          fmt=None, select=None, select_options={}, field=None,
          height_at_top_of_model=None, recursive=False,
-         follow_symlinks=False, um=None, chunk=True, _debug=False):
+         follow_symlinks=False, um=None, chunk=True,
+#         set_auto_mask=True,
+         _debug=False):
     '''Read fields from netCDF, PP or UM fields files.
 
 Files may be on disk or on a OPeNDAP server.
@@ -323,11 +325,11 @@ Office (UK) fields files format files may be read.
                                   verbose=verbose,
                                   aggregate=aggregate,
                                   aggregate_options=aggregate_options,
-                                  selected_fmt=fmt,
-                                  um=um,
+                                  selected_fmt=fmt, um=um,
                                   field=field,
                                   height_at_top_of_model=height_at_top_of_model,
                                   chunk=chunk,
+#                                  set_auto_mask=set_auto_mask,
                                   _debug=_debug)
             
             # --------------------------------------------------------
@@ -501,6 +503,7 @@ def _read_a_file(filename,
                  field=(),
                  height_at_top_of_model=None,
                  chunk=True,
+#                 set_auto_mask=True,
                  _debug=False):
     '''
 
@@ -579,6 +582,7 @@ Read the contents of a single file into a field list.
     if ftype == 'netCDF' and (selected_fmt in (None, 'NETCDF', 'CFA')):
         fields = netcdf_read(filename, fmt=selected_fmt, field=field,
                              verbose=verbose, chunk=chunk,
+#                             set_auto_mask=set_auto_mask,
                              _debug=_debug)
         
     elif ftype == 'UM' and (selected_fmt in (None, 'PP', 'FF')):
@@ -586,7 +590,8 @@ Read the contents of a single file into a field list.
                          verbose=verbose, set_standard_name=True,
                          height_at_top_of_model=height_at_top_of_model,
                          fmt=fmt, word_size=word_size, endian=endian,
-                         chunk=chunk, _debug=_debug)
+                         chunk=chunk, #set_auto_mask=set_auto_mask,
+                         _debug=_debug)
 
         # PP fields are aggregated intrafile prior to interfile
         # aggregation
