@@ -32,7 +32,7 @@ _one_day    = Data(1, 'day')
 _one_hour   = Data(1, 'hour')
 _one_minute = Data(1, 'minute')
 
-# Default monthl lengths in days
+# Default month lengths in days
 _default_month_lengths = [None, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31]
 
 Offset = namedtuple('offset', ('year', 'month', 'day', 'hour',
@@ -293,10 +293,17 @@ Function  Description
 
         if units is not None:
             units = Units(units)
-            self.duration = Data(abs(duration), units)
+            self.duration = Data(abs(duration))
+            if self.duration.Units.istime:
+                self.duration.Units = units
+            else:
+                self.duration = Data(self.duration.array, units)
         else:
             self.duration = abs(Data.asdata(duration))
             units = self.duration.Units
+            if not units.istime:
+                raise ValueError("Bad units: {!r}".format(units))
+
 
         if not (units.iscalendartime or units.istime):
             raise ValueError(
@@ -782,18 +789,18 @@ x.__rmod__(y) <==> y % x
 
         if duration.size != 1:           
             raise ValueError(
-"Can't create {0} with more than one value: {1}".format(
+"Can't create {} with more than one value: {}".format(
     self.__class__.__name__, duration))
             
         if duration < 0:
             raise ValueError(
-"Can't create {0} with a negative duration".format(self.__class__.__name__))
+"Can't create {} with a negative duration".format(self.__class__.__name__))
 
         if not duration.Units.equals(self.duration.Units):
             if method not in ('__eq__', '__ne__', '__lt__', '__le__', '__gt__', '__ge__'):
                 # Operator is not one of ==, !=, >=, >, <=, <                
                 raise ValueError(
-"Can't create {0} of {1!r}".format(self.__class__.__name__, duration.Units))
+"Can't create {} of {!r}".format(self.__class__.__name__, duration.Units))
 
         duration.Units = self_units
 
@@ -859,6 +866,7 @@ x.__rmod__(y) <==> y % x
     dt: `cf.Datetime`
 
 :Returns:
+
 .. versionadded:: 1.4
         '''
         return Datetime(*[(i if j is None else j)
@@ -1056,7 +1064,7 @@ specific calendar.
             length = month_lengths[month]
             if month == leap_month and year % 4 == 0:
                 length += 1
-    
+
         return length
     #--- End: def
 
@@ -1542,7 +1550,7 @@ consistent with the time duration's offset.
         '''
         abs_self = abs(self)
         dt0 = self._offset(dt)
-
+        
         if dt0 > dt:
             dt1 = dt0
             dt0 = dt1 - abs_self
